<?php
// Include PHPSpreadsheet
require 'vendor/autoload.php';

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Chart\Chart;
use PhpOffice\PhpSpreadsheet\Chart\Title;
use PhpOffice\PhpSpreadsheet\Chart\Series;

// Initialize a new Spreadsheet object
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();

// Sample data
$data = [
    ['Month', 'Sales'],
    ['January', 100],
    ['February', 200],
    ['March', 150],
];

// Populate the Excel sheet with data
foreach ($data as $rowIndex => $row) {
    foreach ($row as $colIndex => $value) {
        $sheet->setCellValueByColumnAndRow($colIndex + 1, $rowIndex + 1, $value);
    }
}

// Create a new chart object
$chart = new Chart(
    'chart1', // Name of the chart
    new Title('Sales Chart') // Title
);

// Set the data series for the chart
$series = new Series(
    new SeriesValues('Number', 'Worksheet!$B$2:$B$4'), // Data values
    new SeriesValues('String', 'Worksheet!$A$2:$A$4'), // Data labels
    null, // Plot order
    null, // Data marker
    null // Data label
);

// Add the series to the chart
$chart->setPlotArea(new PlotArea(null, [$series]));

// Set the position of the chart
$chart->setTopLeftPosition('A6');
$chart->setBottomRightPosition('H20');

// Add the chart to the worksheet
$sheet->addChart($chart);

// Set headers for Excel file download
header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment;filename="chart_data.xlsx"');
header('Cache-Control: max-age=0');

// Write the spreadsheet to a file
$writer = new Xlsx($spreadsheet);
$writer->save('php://output');
